@@ -1,4 +1,4 @@
-from typing import List, Optional, Tuple
+from typing import List, Optional, Tuple, Dict
 import functools
 import logging
 
@@ -103,12 +103,28 @@ class Molecule(BaseMolecule):
     @classmethod
     def from_rdkit(cls, molecule, random_seed=-1, **kwargs):
         from . import rdutils
-        qcmol = rdutils.rdmol_to_qcelemental(molecule, random_seed=random_seed)
-        kwargs = dict(**kwargs)
-        kwargs["qcmol"] = qcmol
-        obj = cls(**kwargs)
-        obj._rdmol = molecule
-        return obj
+        return rdutils.molecule_from_rdkit(molecule, cls,
+                                           random_seed=random_seed,
+                                           **kwargs)
+
+    def to_rdkit(self):
+        from .rdutils import molecule_to_rdkit
+        return molecule_to_rdkit(self)
+
+    def to_mdanalysis(self):
+        from .mdautils import molecule_to_mdanalysis
+        return molecule_to_mdanalysis(self)
+
+    @property
+    def charges(self):
+        for charge_prop in [
+            self.stage_2_restrained_charges,
+            self.stage_2_unrestrained_charges,
+            self.stage_1_restrained_charges,
+            self.stage_1_unrestrained_charges,
+        ]:
+            if charge_prop is not None:
+                return charge_prop
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -237,6 +253,35 @@ class Molecule(BaseMolecule):
         indices = self.get_smarts_matches(smiles)
         return [Atom.from_molecule(self, indices=ix) for ix in indices]
 
+    def get_sp3_ch_indices(self) -> Dict[int, List[int]]:
+        get_connectivity = None
+        if self._rdmol:
+            try:
+                from .rdutils import get_connectivity
+            except ImportError:
+                pass
+        if get_connectivity is None:
+            try:
+                from .psi4utils import get_connectivity
+            except ImportError:
+                def get_connectivity(x):
+                    return x.qcmol.connectivity
+
+        symbols = self.qcmol.symbols
+        bonds = get_connectivity(self)
+        if bonds is None:
+            bonds = np.empty(0, 3)
+        bonds = np.asarray(bonds)
+        single_bonds = np.isclose(bonds[:, 2], np.ones_like(bonds[:, 2]))
+        groups = {}
+        for i in np.where(symbols == "C")[0]:
+            contains_index = np.any(bonds[:, :2] == i, axis=1)
+            c_bonds = bonds[contains_index & single_bonds][:, :2].astype(int)
+            c_partners = c_bonds[c_bonds != i]
+            if len(c_partners) == 4:
+                groups[i] = c_partners[symbols[c_partners] == "H"]
+        return groups
+
 
 @functools.total_ordering
 class Atom(base.Model):
